@@ -1,8 +1,12 @@
 from ._version import __version__
 from .experiment import MLExperiment, experiment
-from .utils.core_experiment import mle_config, setup_proxy_server
-from .utils.check_single_job import check_single_job_args
-from .utils.core_files_load import load_result_logs, combine_experiments
+from .utils import (
+    mle_config,
+    setup_proxy_server,
+    check_single_job_args,
+    load_result_logs,
+    combine_experiments,
+)
 
 
 __all__ = [
