@@ -6,8 +6,9 @@ from .utils.core_experiment import (
     get_extra_cmd_line_input,
     set_random_seeds,
     setup_proxy_server,
+    mle_config,
 )
-from .utils.helpers import print_framed
+from .utils.helpers import print_framed, get_os_env_ready
 from mle_logging import MLELogger
 from mle_logging.load import load_model
 
@@ -23,6 +24,7 @@ class MLExperiment(object):
         train_config: Union[None, dict] = None,
         log_config: Union[None, dict] = None,
         model_config: Union[None, dict] = None,
+        device_config: Union[None, dict] = None,
     ):
         """Load job configuration for MLE experiment, setup logger & random seeds."""
         setup_proxy_server()
@@ -37,10 +39,11 @@ class MLExperiment(object):
             cmd_args.config_fname,
             cmd_args.experiment_dir,
             cmd_args.seed_id,
-            cmd_args.model_ckpt,
+            cmd_args.model_ckpt_path,
             train_config,
             log_config,
             model_config,
+            device_config,
         )
         # Optional addition of more command line inputs
         extra_config = get_extra_cmd_line_input(extra_args)
@@ -49,11 +52,29 @@ class MLExperiment(object):
         self.train_config = loaded_configs[0]
         self.model_config = loaded_configs[1]
         self.log_config = loaded_configs[2]
+        self.device_config = loaded_configs[3]
         self.extra_config = extra_config
         self.create_jax_prng = create_jax_prng
         self.default_seed = seed_id
         self.seed_id = seed_id
-        self.model_ckpt = cmd_args.model_ckpt
+
+        # Get model ckpt path from command line argument or look in config!
+        self.model_ckpt_path = cmd_args.model_ckpt_path
+        if self.model_ckpt_path is None:  # Based on mle-hyperopt extra dict
+            base_ckpt_names = ["ckpt", "model_ckpt"]
+            extra_ckpt_names = ["sh_ckpt", "pbt_ckpt"]
+            for m in base_ckpt_names:
+                if m in self.train_config.keys():
+                    self.model_ckpt_path = self.train_config[m]
+            if "extra" in self.train_config.keys():
+                for m in extra_ckpt_names:
+                    if m in self.train_config.extra.keys():
+                        self.model_ckpt_path = self.train_config.extra[m]
+
+        # Get data for W&B from commandline (project, group/sweep)
+        self.wb_project = cmd_args.wb_project
+        self.wb_group = cmd_args.wb_group
+        self.wb_name = cmd_args.wb_name
 
         # Make initial setup optional so that configs can be modified ad-hoc
         if auto_setup:
@@ -67,24 +88,64 @@ class MLExperiment(object):
             self.train_config.seed_id = self.default_seed
             self.log_config.seed_id = self.default_seed
             print_framed(
-                f"!!!WARNING!!!: No seed provided - set to default "
+                "!!!WARNING!!!: No seed provided - set to default "
                 f"{self.default_seed}."
             )
 
+        # Setup the device configuration (cuda visibility, jax, etc)
+        if self.device_config is not None:
+            get_os_env_ready(**self.device_config)
+
         self.seed_id = self.train_config.seed_id
         # Set the random seeds for all random number generation
         if self.create_jax_prng:
             # Return JAX random number generating key
-            self.rng = set_random_seeds(self.train_config.seed_id, return_key=True)
+            self.rng = set_random_seeds(
+                self.train_config.seed_id, return_key=True
+            )
         else:
             set_random_seeds(self.train_config.seed_id)
 
         # Initialize the logger for the experiment
+        if "use_wandb" in self.log_config.keys():
+            if self.log_config.use_wandb:
+                # Init empty wandb config dict - if no info provided in config
+                if "wandb_config" not in self.log_config.keys():
+                    self.log_config["wandb_config"] = {}
+
+                # Add data from mle_config if not otherwise provided
+                for k in ["key", "entity"]:
+                    if k not in self.log_config.wandb_config.keys():
+                        self.log_config.wandb_config[k] = mle_config.wandb[k]
+
+                # Add project/group for W&B logging (if provided)
+                if "project" not in self.log_config.wandb_config.keys():
+                    if self.wb_project is not None:
+                        self.log_config.wandb_config[
+                            "project"
+                        ] = self.wb_project
+                    else:
+                        self.log_config.wandb_config["project"] = "prototyping"
+                if "group" not in self.log_config.wandb_config.keys():
+                    if self.wb_group is not None:
+                        self.log_config.wandb_config["group"] = self.wb_group
+                    else:
+                        self.log_config.wandb_config["group"] = None
+                if "name" not in self.log_config.wandb_config.keys():
+                    if self.wb_name is not None:
+                        self.log_config.wandb_config["name"] = self.wb_name
+                    else:
+                        self.log_config.wandb_config["group"] = None
+
         self.log = MLELogger(**self.log_config)
 
         # Load model if checkpoint is provided
-        if self.model_ckpt is not None:
-            self.model_ckpt = load_model(self.model_ckpt, self.log_config.model_type)
+        if self.model_ckpt_path is not None:
+            self.model_ckpt = load_model(
+                self.model_ckpt_path, self.log_config.model_type
+            )
+        else:
+            self.model_ckpt = None
 
     def update_log(
         self,
@@ -96,7 +157,9 @@ class MLExperiment(object):
         save=False,
     ) -> None:
         """Update the MLE_Logger instance with stats, model params & save."""
-        self.log.update(clock_tick, stats_tick, model, plot_fig, extra_obj, save)
+        self.log.update(
+            clock_tick, stats_tick, model, plot_fig, extra_obj, save
+        )
 
     def ready_to_log(self, update_counter: int) -> bool:
         """Check whether update_counter is modulo of log_every_k_steps in logger."""
