@@ -1,7 +1,7 @@
 from .hyper_logger import HyperoptLogger
-from .mle_wrapper import MLE_Hyperoptimisation
+from .mle_batch_search import MLE_BatchSearch
 
 __all__ = [
     "HyperoptLogger",
-    "MLE_Hyperoptimisation",
+    "MLE_BatchSearch",
 ]
