@@ -1,6 +1,6 @@
 import os
 from typing import Dict, Union
-from ..hyperopt import HyperoptLogger, MLE_Hyperoptimisation
+from ..hyperopt import HyperoptLogger, MLE_BatchSearch
 from pathlib import Path
 from mle_monitor import MLEProtocol
 
@@ -14,6 +14,7 @@ def run_hyperparameter_search(
     ],
     message_id: Union[str, None] = None,
     protocol_db: Union[MLEProtocol, None] = None,
+    debug_mode: bool = False,
 ) -> None:
     """Run a hyperparameter search experiment for multiple configurations."""
     if type(meta_job_args["base_train_config"]) == list:
@@ -28,7 +29,7 @@ def run_hyperparameter_search(
         experiment_dirs = [meta_job_args["experiment_dir"]]
 
     for i in range(len(config_files)):
-        run_single_config_search(
+        run_single_batch_search(
             resource_to_run,
             meta_job_args["base_train_fname"],
             config_files[i],
@@ -37,10 +38,11 @@ def run_hyperparameter_search(
             param_search_args,
             message_id,
             protocol_db,
+            debug_mode,
         )
 
 
-def run_single_config_search(
+def run_single_batch_search(
     resource_to_run: str,
     train_fname: str,
     train_config: str,
@@ -51,6 +53,7 @@ def run_single_config_search(
     ],
     message_id: Union[str, None] = None,
     protocol_db: Union[MLEProtocol, None] = None,
+    debug_mode: bool = False,
 ) -> None:
     """Run a hyperparameter search experiment for a single configuration."""
     # 1. Setup the hyperlogger for the experiment
@@ -61,11 +64,20 @@ def run_single_config_search(
     hyper_log = HyperoptLogger(hyperlog_fname, **param_search_args["search_logging"])
 
     # 2. Initialize the hyperparameter optimizer class
-    search_types = ["random", "grid", "smbo", "nevergrad", "coordinate"]
+    search_types = [
+        "Random",
+        "Grid",
+        "SMBO",
+        "Nevergrad",
+        "Coordinate",
+        "Halving",
+        "Hyperband",
+        "PBT",
+    ]
     assert param_search_args["search_config"]["search_type"] in search_types
 
-    # Add resource budget to nevergrad configuration
-    if param_search_args["search_config"]["search_type"] == "nevergrad":
+    # Add budgets to config (special cases: Nevergrad & PBT)
+    if param_search_args["search_config"]["search_type"] == "Nevergrad":
         param_search_args["search_config"]["search_config"][
             "num_workers"
         ] = param_search_args["search_resources"]["num_evals_per_batch"]
@@ -74,6 +86,11 @@ def run_single_config_search(
             * param_search_args["search_resources"]["num_search_batches"]
         )
 
+    elif param_search_args["search_config"]["search_type"] == "PBT":
+        param_search_args["search_resources"][
+            "num_evals_per_batch"
+        ] = param_search_args["search_config"]["search_config"]["num_workers"]
+
     # 4. Compute remaining jobs/batches for sync/async scheduling of jobs
     if "search_schedule" in param_search_args["search_config"].keys():
         if param_search_args["search_config"]["search_schedule"] == "async":
@@ -89,14 +106,21 @@ def run_single_config_search(
                 "num_search_batches"
             ] -= completed_batches
     else:
-        completed_batches = int(
-            hyper_log.iter_id
-            / param_search_args["search_resources"]["num_evals_per_batch"]
-        )
-        param_search_args["search_resources"]["num_search_batches"] -= completed_batches
+        # Default to batch case - if no search_schedule provided!
+        if param_search_args["search_config"]["search_type"] not in [
+            "Halving",
+            "Hyperband",
+        ]:
+            completed_batches = int(
+                hyper_log.iter_id
+                / param_search_args["search_resources"]["num_evals_per_batch"]
+            )
+            param_search_args["search_resources"][
+                "num_search_batches"
+            ] -= completed_batches
 
     # 5. Run the jobs (only remaining jobs if reloaded)
-    hyper_opt_instance = MLE_Hyperoptimisation(
+    hyper_opt = MLE_BatchSearch(
         hyper_log,
         resource_to_run,
         single_job_args,
@@ -105,7 +129,25 @@ def run_single_config_search(
         experiment_dir,
         **param_search_args["search_config"],
         message_id=message_id,
-        protocol_db=protocol_db
+        protocol_db=protocol_db,
+        debug_mode=debug_mode
     )
 
-    hyper_opt_instance.run_search(**param_search_args["search_resources"])
+    # Special Case: Hyperband & Successive Halving -> Compute required
+    # resources post strategy instantiation -> No. of jobs changes w. batch id!
+    if param_search_args["search_config"]["search_type"] == "Halving":
+        param_search_args["search_resources"][
+            "num_evals_per_batch"
+        ] = hyper_opt.strategy.evals_per_batch
+        param_search_args["search_resources"][
+            "num_search_batches"
+        ] = hyper_opt.strategy.num_sh_batches
+    elif param_search_args["search_config"]["search_type"] == "Hyperband":
+        param_search_args["search_resources"][
+            "num_evals_per_batch"
+        ] = hyper_opt.strategy.evals_per_batch
+        param_search_args["search_resources"][
+            "num_search_batches"
+        ] = hyper_opt.strategy.num_hb_batches
+
+    hyper_opt.run_search(**param_search_args["search_resources"])
