@@ -3,7 +3,10 @@ from mle_toolbox import check_single_job_args
 
 
 def run_single_config(
-    resource_to_run: str, meta_job_args: dict, single_job_args: dict
+    resource_to_run: str,
+    meta_job_args: dict,
+    single_job_args: dict,
+    debug_mode: bool = False,
 ) -> None:
     """
     Run a single experiment locally, remote or in cloud.
@@ -21,11 +24,12 @@ def run_single_config(
     single_job_args = check_single_job_args(resource_to_run, single_job_args.copy())
     # 1. Instantiate the experiment class
     experiment = MLEJob(
-        resource_to_run,
-        meta_job_args["base_train_fname"],
-        single_job_args,
-        meta_job_args["base_train_config"],
-        meta_job_args["experiment_dir"],
+        resource_to_run=resource_to_run,
+        job_filename=meta_job_args["base_train_fname"],
+        job_arguments=single_job_args,
+        config_filename=meta_job_args["base_train_config"],
+        experiment_dir=meta_job_args["experiment_dir"],
+        debug_mode=debug_mode,
     )
     # 2. Run the single experiment
     _ = experiment.run()
