@@ -8,23 +8,6 @@ from .generate_figures import FigureGenerator
 from ..launch import prepare_logger
 
 
-try:
-    import markdown2
-except ModuleNotFoundError as err:
-    raise ModuleNotFoundError(
-        f"{err}. You need to install `markdown2` "
-        "to use the `mle_toolbox.report` module."
-    )
-
-try:
-    from xhtml2pdf import pisa
-except ModuleNotFoundError as err:
-    raise ModuleNotFoundError(
-        f"{err}. You need to install `xhtml2pdf` "
-        "to use the `mle_toolbox.report` module."
-    )
-
-
 class ReportGenerator:
     """
     Generate md/html/pdf report of experiment from db/results dir.
@@ -50,7 +33,8 @@ class ReportGenerator:
         else:
             time_t = datetime.now().strftime("%m/%d/%Y %I:%M:%S %p")
             pull_question = input(
-                time_t + " Can't find results. Do you"
+                time_t
+                + " Can't find results. Do you"
                 " want to pull remote results [Y/N]:  "
             )
             pull_bool = pull_question == "Y"
@@ -70,7 +54,7 @@ class ReportGenerator:
                 )
             else:
                 self.experiment_dir = input(
-                    time_t + " Please provide relative" " path to results:  "
+                    time_t + " Please provide relative path to results:  "
                 )
 
         # Create a directory for the reports to be stored in
@@ -109,15 +93,19 @@ class ReportGenerator:
         search_vars, search_targets = self.get_hypersearch_data()
 
         if len(search_vars) > 1:
-            _ = self.fig_generator.generate_all_2D_figures(search_vars, search_targets)
+            _ = self.fig_generator.generate_all_2D_figures(
+                search_vars, search_targets
+            )
 
         self.figure_fnames = abs_figure_paths(self.fig_generator.figures_dir)
         self.logger.info(
-            f"Report - GENERATED - figures - total:" f" {len(self.figure_fnames)}"
+            f"Report - GENERATED - figures - total: {len(self.figure_fnames)}"
         )
 
         # 3. Add these figures to the html report file used to generate PDF
-        self.html_report_fname = os.path.join(self.reports_dir, self.e_id + ".html")
+        self.html_report_fname = os.path.join(
+            self.reports_dir, self.e_id + ".html"
+        )
         self.html_text = generate_html(
             self.html_report_fname, self.markdown_text, self.figure_fnames
         )
@@ -129,27 +117,36 @@ class ReportGenerator:
 
         # 5. Generate the PDF file.
         if self.pdf_gen:
-            self.pdf_report_fname = os.path.join(self.reports_dir, self.e_id + ".pdf")
+            self.pdf_report_fname = os.path.join(
+                self.reports_dir, self.e_id + ".pdf"
+            )
             generate_pdf(self.pdf_report_fname, self.html_report_fname)
             self.logger.info(f'Report - .pdf GENERATED: {self.e_id + ".pdf"}')
 
     def get_hypersearch_data(self):
         """Get hypersearch variables + targets for 2D visualization loop."""
         search_vars, search_targets = [], []
-        if "search_params" in self.report_data["job_spec_args"]["search_config"]:
-            params = self.report_data["job_spec_args"]["search_config"]["search_params"]
+        if (
+            "search_params"
+            in self.report_data["job_spec_args"]["search_config"]
+        ):
+            params = self.report_data["job_spec_args"]["search_config"][
+                "search_params"
+            ]
             for type, var_dict in params.items():
                 for var_name in var_dict.keys():
                     search_vars.append(var_name)
-            search_targets = self.report_data["job_spec_args"]["search_logging"][
-                "eval_metrics"
-            ]
+            search_targets = self.report_data["job_spec_args"][
+                "search_logging"
+            ]["eval_metrics"]
         if isinstance(search_targets, str):
             search_targets = [search_targets]
         return search_vars, search_targets
 
 
-def construct_markdown_table(data_dict, exclude_keys=[], table_entries_per_row=2):
+def construct_markdown_table(
+    data_dict, exclude_keys=[], table_entries_per_row=2
+):
     """Construct a markdown table from a dictionary with data."""
     table, current_row, entry_counter = [], {}, 0
     for k, value in data_dict.items():
@@ -205,13 +202,19 @@ def generate_markdown(e_id, md_report_fname, report_data):
     config_keys = ["loaded_config"]
     single_keys = ["purpose", "project_name"]
 
-    md_generator = MarkdownGenerator(filename=md_report_fname, enable_write=False)
+    md_generator = MarkdownGenerator(
+        filename=md_report_fname, enable_write=False
+    )
     with md_generator as doc:
-        doc.addHeader(1, "Report: " + report_data["project_name"] + " - " + e_id)
+        doc.addHeader(
+            1, "Report: " + report_data["project_name"] + " - " + e_id
+        )
 
         # Meta-Data of the Experiment
         doc.addHeader(2, "Experiment Meta-Data.")
-        doc.writeTextLine(f'{doc.addBoldedText("Purpose:")} ' + report_data["purpose"])
+        doc.writeTextLine(
+            f'{doc.addBoldedText("Purpose:")} ' + report_data["purpose"]
+        )
 
         doc.addHeader(3, "General Job Settings.")
         hyper_table = construct_markdown_table(
@@ -231,14 +234,21 @@ def generate_markdown(e_id, md_report_fname, report_data):
         doc.addTable(dictionary_list=job_table)
 
         doc.addHeader(3, "Job-Specific-Arguments.")
-        if report_data["meta_job_args"]["experiment_type"] == "hyperparameter-search":
+        if (
+            report_data["meta_job_args"]["experiment_type"]
+            == "hyperparameter-search"
+        ):
             search_table = construct_hypersearch_table(
                 report_data["job_spec_args"]["search_config"]["search_params"]
             )
             doc.addTable(dictionary_list=search_table)
             doc.writeTextLine(
                 f'{doc.addBoldedText("Metrics:")} '
-                + str(report_data["job_spec_args"]["search_logging"]["eval_metrics"])
+                + str(
+                    report_data["job_spec_args"]["search_logging"][
+                        "eval_metrics"
+                    ]
+                )
             )
 
         # TODO: Add more different experiment type configurations.
@@ -258,7 +268,7 @@ def generate_markdown(e_id, md_report_fname, report_data):
                 report_data["loaded_config"][0]["model_config"]
             )
             doc.addTable(dictionary_list=model_table)
-        except:
+        except Exception:
             pass
 
         doc.addHeader(3, "Logging Configuration.")
@@ -276,17 +286,28 @@ def generate_markdown(e_id, md_report_fname, report_data):
 
 def generate_html(html_report_fname, markdown_text, figure_fnames):
     """Generates HTML report from markdown text + adds all figures."""
+    try:
+        import markdown2
+    except ModuleNotFoundError as err:
+        raise ModuleNotFoundError(
+            f"{err}. You need to install `markdown2` "
+            "to use the `mle_toolbox.report` module."
+        )
     with open(html_report_fname, "w") as output_file:
         html_text = markdown2.markdown(markdown_text, extras=["tables"])
         # Add figure inclusion to HTML text
         html_text = (
-            '<a href="https://roberttlange.github.io/mle-infrastructure/images/logos/toolbox.png"><img src="https://roberttlange.github.io/mle-infrastructure/images/logos/toolbox.png" width="150" align="right" /></a>'
+            '<a href="https://roberttlange.github.io/mle-infrastructure/images/logos/toolbox.png"><img'
+            ' src="https://roberttlange.github.io/mle-infrastructure/images/logos/toolbox.png"'
+            ' width="150" align="right" /></a>'
             + html_text
         )
         # By default: 2 Figures per row - 45% width
         counter = 0
         for fig in figure_fnames:
-            html_text += f'<img src="{fig}" width="350"' + 'style="margin-right:20px">'
+            html_text += (
+                f'<img src="{fig}" width="350"' + 'style="margin-right:20px">'
+            )
             counter += 1
             if counter % 2 == 0:
                 html_text += "<br>"
@@ -303,6 +324,14 @@ def generate_pdf(pdf_report_fname, html_report_fname):
 
     file = codecs.open(html_report_fname, "r", "utf-8")
     source_html = file.read()
+
+    try:
+        from xhtml2pdf import pisa
+    except ModuleNotFoundError as err:
+        raise ModuleNotFoundError(
+            f"{err}. You need to install `xhtml2pdf` "
+            "to use the `mle_toolbox.report` module."
+        )
     _ = pisa.CreatePDF("<html>" + source_html + "</html>", dest=result_file)
     # close output file
     result_file.close()  # close output file
