@@ -17,8 +17,11 @@ from .core_files_load import (
     load_result_logs,
     combine_experiments,
 )
-from .load_hyper_log import load_hyper_log
-from .helpers import print_framed, get_jax_os_ready, save_pkl_object
+from .hyper_log import load_hyper_log
+from .helpers import print_framed, get_os_env_ready, save_pkl_object
+
+# Backward compatibility of get_os_env_ready
+from .helpers import get_os_env_ready as get_jax_os_ready
 from .protocol_data import compose_protocol_data
 
 
@@ -32,14 +35,16 @@ __all__ = [
     "load_job_config",
     "load_experiment_config",
     "setup_proxy_server",
+    "mle_config",
+    "check_single_job_args",
     "load_mle_toolbox_config",
     "load_pkl_object",
     "load_result_logs",
     "combine_experiments",
     "load_hyper_log",
     "print_framed",
+    "get_os_env_ready",
     "get_jax_os_ready",
     "save_pkl_object",
     "compose_protocol_data",
-    "check_single_job_args",
 ]
