@@ -53,6 +53,8 @@ def check_single_job_args(resource_to_run: str, job_arguments: dict):
         full_job_arguments = gcp_check_job_args(job_arguments)
     elif resource_to_run == "local":
         full_job_arguments = local_check_job_args(job_arguments)
+    else:
+        raise ValueError("Please a valid compute resource.")
     return full_job_arguments
 
 
@@ -150,7 +152,7 @@ def load_experiment_config(cmd_args: dict) -> DotMap:
     ]
     assert (
         experiment_type in all_experiment_types
-    ), "Job type has to be in {all_experiment_types}."
+    ), f"Job type has to be in {all_experiment_types}."
 
     if experiment_type == "single-config":
         assert "single_job_args" in config.keys()
@@ -253,11 +255,37 @@ def parse_experiment_args(
     # Optional: Checkpoint path to potentially reload model
     parser.add_argument(
         "-model_ckpt",
-        "--model_ckpt",
+        "--model_ckpt_path",
         action="store",
         default=None,
-        help="Model checkpoint to reload.",
+        help="Model checkpoint path to reload.",
     )
+
+    # Optional: W&B project name & group, name (experiment purpose)
+    parser.add_argument(
+        "-wb_project",
+        "--wb_project",
+        action="store",
+        default=None,
+        help="W&B project name to log to.",
+    )
+
+    parser.add_argument(
+        "-wb_group",
+        "--wb_group",
+        action="store",
+        default=None,
+        help="W&B group name to log to - short purpose of experiment.",
+    )
+
+    parser.add_argument(
+        "-wb_name",
+        "--wb_name",
+        action="store",
+        default=None,
+        help="W&B run name to log to - short purpose of experiment.",
+    )
+
     cmd_args, extra_args = parser.parse_known_args()
     return cmd_args, extra_args
 
@@ -265,12 +293,13 @@ def parse_experiment_args(
 def load_job_config(
     config_fname: str,
     experiment_dir: str,
-    seed_id: Union[None, int],
-    model_ckpt: Union[None, str],
+    seed_id: Union[None, int] = 0,
+    model_ckpt: Union[None, str] = None,
     train_config_ext: Union[None, dict] = None,
     log_config_ext: Union[None, dict] = None,
     model_config_ext: Union[None, dict] = None,
-) -> Tuple[DotMap, DotMap, DotMap]:
+    device_config_ext: Union[None, dict] = None,
+) -> Tuple[DotMap, DotMap, DotMap, DotMap]:
     """Prepare job config files for experiment run (add seed id, etc.)."""
     # Load .json/.yaml job config + add config fname/experiment dir
     if os.path.exists(config_fname):
@@ -312,6 +341,13 @@ def load_job_config(
     train_config = DotMap(config["train_config"], _dynamic=False)
     log_config = DotMap(config["log_config"], _dynamic=False)
 
+    # Add device config to the standard configurations
+    # In experiment setup this will be passed to get_os_env_ready
+    if "device_config" in config.keys():
+        device_config = DotMap(config["device_config"], _dynamic=False)
+    else:
+        device_config = None
+
     # Add device to train on if not already set in the config file
     if "device_name" in train_config.keys():
         device_name = "cpu"
@@ -342,7 +378,7 @@ def load_job_config(
     if model_ckpt is not None:
         train_config.model_ckpt = model_ckpt
 
-    # If train_config_ext, log_config_ext and model_config_ext
+    # If train_config_ext, log_config_ext, model_config_ext, device_config_ext
     # manually provided copy over all key, value pairs
     if train_config_ext is not None:
         for k, v in train_config_ext.items():
@@ -355,7 +391,12 @@ def load_job_config(
             model_config = DotMap({})
         for k, v in model_config_ext.items():
             model_config[k] = v
-    return train_config, model_config, log_config
+    if device_config_ext is not None:
+        if device_config is None:
+            device_config = DotMap({})
+        for k, v in device_config_ext.items():
+            device_config[k] = v
+    return train_config, model_config, log_config, device_config
 
 
 def get_extra_cmd_line_input(extra_cmd_args: Union[list, None] = None):
