@@ -17,33 +17,36 @@ def save_pkl_object(obj, filename: str):
         pickle.dump(obj, output, pickle.HIGHEST_PROTOCOL)
 
 
-def get_jax_os_ready(
+def get_os_env_ready(
     num_devices: int = 1,
-    num_threads: int = 1,
     mem_prealloc_bool: bool = False,
     mem_prealloc_frac: float = 0.9,
     device_type: str = "cpu",
-):
-    """Helper to set up os variables for JAX/XLA experiment."""
-    # Set number of devices (CPU cores/GPUs/TPUs) - helps with pmap testing
-    os.environ["XLA_FLAGS"] = (
-        "--xla_force_host_platform_device_count" + f"={num_devices}"
-    )
-    # TODO: Set threads for XLA multithreading
+) -> None:
+    """Helper to set up os variables e.g. for Cuda/JAX/XLA experiment."""
+    # Set environment variables for usage of CPU cores
     if device_type == "cpu":
-        os.environ["XLA_FLAGS"] += os.pathsep + (
-            "--xla_cpu_multi_thread_eigen=false "
-            "intra_op_parallelism_threads={num_threads}"
+        # Set number of devices (CPU cores/GPUs/TPUs) - helps with pmap testing
+        os.environ["XLA_FLAGS"] = (
+            "--xla_force_host_platform_device_count" + f"={num_devices}"
+        )
+        os.environ["CUDA_VISIBLE_DEVICES"] = ""
+        print(f"MLExperiment: Set XLA settings to {num_devices} CPUs.")
+
+    # Set environment variables for usage & memory preallocation on GPU
+    if device_type == "gpu":
+        # Set visible devices - Jax greedily grabs all availabe devices on node!
+        os.environ["CUDA_VISIBLE_DEVICES"] = ",".join(
+            [str(i) for i in range(num_devices)]
+        )
+        os.environ["XLA_PYTHON_CLIENT_PREALLOCATE"] = (
+            "True" if mem_prealloc_bool else "False"
         )
-    # Set environment variables for memory preallocation on GPU
-    elif device_type == "gpu":
-        os.environ["XLA_PYTHON_CLIENT_PREALLOCATE"] = mem_prealloc_bool
         os.environ["XLA_PYTHON_CLIENT_MEM_FRACTION"] = f"{mem_prealloc_frac}"
-    # Set environment variables for TPU usage
-    # TODO: This only works for colab (?) - need to install jaxlib version!
-    # Tackle this once I get to automated GCP setup!
+        print(f"MLExperiment: Set XLA settings to {num_devices} GPUs.")
+
+    #  Set environment variables for TPU usage - only works for colab
     elif device_type == "tpu":
         import jax.tools.colab_tpu
 
         jax.tools.colab_tpu.setup_tpu()
-    return
