@@ -1,7 +1,14 @@
 import numpy as np
-import matplotlib.pyplot as plt
-import matplotlib.animation as animation
-import seaborn as sns
+
+
+try:
+    import matplotlib.pyplot as plt
+    import matplotlib.animation as animation
+    import seaborn as sns
+except ImportError:
+    raise ImportError(
+        "You need to install `matplotlib` & `seaborn` to use plotting" " utilities."
+    )
 
 
 def animate_1D_lines(
@@ -60,9 +67,9 @@ class AnimatedLine(object):
         self.ax.set_xlabel(xlabel, fontsize=20)
 
         for tick in self.ax.xaxis.get_major_ticks():
-            tick.label.set_fontsize(20)
+            tick.label1.set_fontsize(20)
         for tick in self.ax.yaxis.get_major_ticks():
-            tick.label.set_fontsize(20)
+            tick.label1.set_fontsize(20)
         # Then setup FuncAnimation.
         self.ani = animation.FuncAnimation(
             self.fig,
@@ -85,7 +92,9 @@ class AnimatedLine(object):
                 label = self.base_label + " " + str(l_id + 1)
             self.line.append(
                 self.ax.plot(
-                    np.arange(0, self.dt * y.shape[0], self.dt), y[0, l_id], label=label
+                    np.arange(0, self.dt * y.shape[0], self.dt),
+                    y[0, l_id],
+                    label=label,
                 )[0]
             )
 
@@ -107,7 +116,8 @@ class AnimatedLine(object):
         sub_data = self.data[: (i + 1), :]
         for l_id, l in enumerate(self.line):
             l.set_data(
-                np.arange(0, self.dt * sub_data.shape[0], self.dt), sub_data[:, l_id]
+                np.arange(0, self.dt * sub_data.shape[0], self.dt),
+                sub_data[:, l_id],
             )
         self.t = self.t + self.dt
         self.ax.set_title(self.title + r" $t={:.1f}$".format(self.t), fontsize=25)
